@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2018,2019,2020,2021, Stephen Goadhouse <sgoadhouse@virginia.edu>
+# Copyright (c) 2018,2019,2020,2021,2022 Stephen Goadhouse <sgoadhouse@virginia.edu>
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -50,12 +50,19 @@ import argparse
 
 from datetime import datetime
 
-# matplotlib.pyplot is needed for plotting waveform data to screen
-# (very convenient). If do not want to install this very useful Python
-# package, then remove this import and search for 'plt.' below and
-# remove the plotting code.
-import matplotlib.pyplot as plt
-
+PLOT = True
+if (PLOT):
+    try:
+        import matplotlib.pyplot as plt
+    except:
+        print('matplotlib.pyplot is needed for plotting waveform data to screen')
+        print('(very convenient). Please install it with "pip install matplotlib".\n')
+        print('If you do not want to install this very useful Python')
+        print('package, then change line "PLOT = True" to "PLOT = False" in')
+        print('the file "oscope.py"')
+        sys.exit(-1)
+    
+    
 from oscope_scpi import Oscilloscope
 
 def handleFilename(fname, ext, unique=True, timestamp=True):
@@ -98,7 +105,7 @@ def parse(scope):
     parser = argparse.ArgumentParser(description='Access Agilent/KeySight MSO3034A scope')
     parser.add_argument('--hardcopy', '-y', metavar='outfile.png', help='grab hardcopy of scope screen and output to named file as a PNG image')
     parser.add_argument('--waveform', '-w', nargs=2, metavar=('channel', 'outfile.npz'), action='append',
-                        help='grab waveform data of channel ('+ str(scope.chanAllValidList).strip('[]') + ') and output to named file as a Numpy NPZ file (see oscopeplot.py)')
+                        help='grab waveform data of channel ('+ str(scope.chanAllValidList).strip('[]') + ') and output to named file as a Numpy NPZ file (see oscopeplot.py or oscopecsv.py)')
     parser.add_argument('--setup_save', '-s', metavar='outfile.stp', help='save the current setup of the oscilloscope into the named file')
     parser.add_argument('--setup_load', '-l', metavar='infile.stp', help='load the current setup of the oscilloscope from the named file')
     parser.add_argument('--statistics', '-t', action='store_true', help='dump to the output the current displayed measurements')
@@ -266,7 +273,7 @@ def main():
                                 'RMS - Full Screen',
                 ]
                 for meas in measurements:
-                    if (meas is ''):
+                    if (meas == ''):
                         # use a blank string to put in an extra line
                         print()
                     else:
@@ -323,7 +330,7 @@ def main():
 
                     # Plot received data to screen so user can see what they got before saving the file.
                     # However, if the lengths do not match, cannot plot. This can happen if channel is PODx and data are bits.
-                    if (len(x) == len(y)):
+                    if (PLOT and (len(x) == len(y))):
                         print("Close the plot window to continue...")
                         fig, (ax1, ax2) = plt.subplots(1, 2)
                         ax1.plot(x, y)      # plot the data
